@@ -55,7 +55,7 @@ class AWSExporter(Exporter):
         except Exception:
             # Do not log Exception details, becuase it contains secret informations like a Openstack password!
             self.logger.error(
-                f"Phoebe AWS: Can not fetch AWS data."
+                "Phoebe AWS: Can not fetch AWS data."
             )
             raise
 
